/**
 * Handle task command.
 * @function apemanTsk
 * @memberof module:apeman-task/lib
 */

'use strict'

const argx = require('argx')
const co = require('co')
const runTask = require('./tasking/run_task')
const listTasks = require('./tasking/list_tasks')
const apemanfile = require('apemanfile')

/** @lends apemanTsk */
function apemanTsk (name, options) {
  let args = argx(arguments)
  if (args.pop('function')) {
    throw new Error('[apeman-task] Callback is no longer supported. Use promise instead.')
  }
  options = args.pop('object') || {}
  name = args.remain()
    .filter((name) => !!name)
    .reduce((a, b) => [].concat(a, b), [])

  let configuration = apemanfile(options.configuration || null)
  let here = process.cwd()
  let cwd = configuration.$cwd || process.cwd()

  return co(function * () {
    process.chdir(cwd)
    process.emit('apeman:task:begin')
    let result
    if (name.length > 0) {
      result = yield runTask(configuration, name, {
        verbose: options.verbose
      })
    } else {
      result = yield listTasks(configuration)
    }
    process.emit('apeman:task:done')
    process.chdir(here)
    return result
  })
}

module.exports = apemanTsk
