/**
 * List available tasks.
 * @memberof module:apeman-task
 * @function listTasks
 * @param {Apemanfile} - Apemanfile to work with.
 * @param {object} options - Optional settings.
 * @returns {Promise}
 */
'use strict'

const argx = require('argx')
const ListLogger = require('../logging/list_logger')

/** @lends listTasks */
function listTasks (configuration, options) {
  let args = argx(arguments)
  configuration = args.shift()
  options = args.pop('object') || {}

  let $tasks = configuration.get('$tasks') || {}
  let $children = configuration.$children || {}

  let $childTasks = Object.keys($children).map((name) => {
    let $child = $children[ name ]
    return ({
      namespace: name,
      tasks: $child.get('$tasks'),
      cwd: $child.$cwd
    } || {})
  })
  let logger = new ListLogger({
    verbose: options.verbose
  })
  logger.logList($tasks, $childTasks)
  return Promise.resolve(true)
}

module.exports = listTasks
